subsample <- function(newdata, nsub, firstorderinputinterpolation){
    ## Generate subsampled data set, if needed
    if(nsub < 1){
        ## No subsampling
        data <- newdata
    }else{
        ## The time vector subsampled with nsub for each time interval
        tmp <- c(sapply(1:(nrow(newdata)-1), function(i){
            seq(newdata$t[i], newdata$t[i+1], len=nsub+2)[-(nsub+2)]
        }))
        tsub <- c(tmp, newdata$t[nrow(newdata)])
        ## Interpolate the time series of observations
        it <- which(names(newdata) %in% c("t","time"))
        tmp <- sapply((1:ncol(newdata))[-it], function(i){
            approx(x=newdata$t, y=newdata[ ,i], xout=tsub, method=c("constant","linear")[firstorderinputinterpolation+1])$y
        })
        colnames(tmp) <- names(newdata)[-it]
        data <- data.frame(t=tsub, tmp)
    }
    return(data)
}

## ## Test it
## newdata <- data.frame(t=c(1:5,10,12,14))
## newdata$x <- 1:nrow(newdata)
## newdata$y <- nrow(newdata):1
## ##
## data <- subsample(newdata, nsub=10, firstorder=TRUE)
## plot(data$t, data$x)
## points(newdata$t, newdata$x, col=2, cex=2)

## nrow(newdata)
## nrow(data)
